#' @name AndradeEx8.11
#' @title Comparação entre o Peso Vivo e o Peso Jejum do Gado Crioulo
#'     Lageano
#' @description Para comparar o peso vivo e o peso jejum do gado crioulo
#'     lageano, um pesquisador selecionou aleatoriamente uma amostra de
#'     15 animais e anotou seus pesos.
#' @format Um \code{data.frame} com 30 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{animal}}{Fator de 15 níveis qualitativos, que são
#'     os animais.}
#'
#' \item{\code{estado}}{Fator de 2 níveis qualitativos, que indica
#'     o estado (vivo ou jejum) em que o animal foi pesado.}
#'
#' \item{\code{peso}}{Peso do animais, em kg.}
#'
#' }
#' @keywords AASP
#' @source Andrade, D. F., Ogliari, P. J. (2010). Estatística para as
#'     ciências agrárias e biológicas com noções de experimentação (2nd
#'     ed.). Florianópolis, SC. Editora da UFSC. (Capítulo 8, Exercício
#'     11, pág. 409)
#' @examples
#'
#' data(AndradeEx8.11)
#' str(AndradeEx8.11)
#'
#' # Dados apresentados em formato largo ("wide")
#' library(reshape2)
#' (da <- dcast(AndradeEx8.11, animal ~ estado, value.var = "peso"))
#'
#' # Pares de peso para cada animal
#' library(lattice)
#' dotplot(animal ~ peso,
#'         groups = estado,
#'         auto.key = list(title = "Estado",
#'                         cex.title = 1.1,
#'                         columns = 2),
#'         data = AndradeEx8.11,
#'         xlab = "Peso (kg)",
#'         ylab = "Animal")
#'
#' # Distribuição das diferenças
#' densityplot(~jejum - vivo, data = da)
#'

NULL
