% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AndradeEx8.9.R
\name{AndradeEx8.9}
\alias{AndradeEx8.9}
\title{Estudo da Quantidade de Proteínas após Operação}
\format{Um \code{data.frame} com 34 observações e 3 variáveis, em que

\describe{

\item{\code{paciente}}{Indica os pacientes sujeitos a operação.}

\item{\code{periodo}}{Período em que foi mensurada a quantidade de
    proteínas totais no plasma (antes ou depois da operação).}

\item{\code{prot}}{Quantidade de proteínas totais no plasma.}

}}
\source{
Andrade, D. F., Ogliari, P. J. (2010). Estatística para as
    ciências agrárias e biológicas com noções de experimentação (2nd
    ed.). Florianópolis, SC. Editora da UFSC. (Capítulo 8, Exercício
    9, pág. 408)
}
\description{
Estudo sobre a influência de uma determinada operação,
    realizada em portadores de esquistossomose mansônica, na
    quantidade de proteínas totais no plasma. No estudo mensurou-se a
    quantidade de proteínas antes e depois da operação.
}
\examples{

data(AndradeEx8.9)
str(AndradeEx8.9)

# Dados apresentados em formato largo ("wide")
library(reshape2)
(da <- dcast(AndradeEx8.9, paciente ~ periodo, value.var = "prot"))

# Pares de peso para cada animal
library(lattice)
dotplot(prot ~ paciente,
        groups = periodo,
        auto.key = list(title = "Período",
                        cex.title = 1.1,
                        columns = 2),
        type = "p",
        data = AndradeEx8.9,
        xlab = "Paciente",
        ylab = "Quantidade de Proteínas Totais no Plasma")

# Distribuição das diferenças
densityplot(~antes - depois, data = da)

# Testes de hipóteses
t.test(prot ~ periodo, paired = TRUE, data = AndradeEx8.9)
t.test(da$antes - da$depois)

}
\keyword{AASP}

